@@ -6,7 +6,7 @@ class ZoneminderError(Exception):
 
     def __init__(self, value=None):
         """Create a generic exception."""
-        super(ZoneminderError, self).__init__(value)
+        super().__init__(value)
         self.value = value
 
     def __str__(self):
